## Improvement Goals

### Motivation

- **Trigger**: {{editTrigger}}
- **User Feedback**: {{userFeedback}}
- **Success Issues**: {{successIssues}}

### User Experience Issues

{{#uxIssues}}

- {{.}}
  {{/uxIssues}}

### Performance Gaps

{{#performanceGaps}}

- {{.}}
  {{/performanceGaps}}

### Growth Opportunities

{{#growthOpportunities}}

- {{.}}
  {{/growthOpportunities}}

### Instruction Style Considerations

- **Current Style**: {{currentStyle}}
- **Desired Changes**: {{styleChanges}}
- **Style Fit Assessment**: {{styleFit}}

### Prioritized Improvements

#### Critical (Must Fix)

{{#criticalItems}}

1. {{.}}
   {{/criticalItems}}

#### Important (Should Fix)

{{#importantItems}}

1. {{.}}
   {{/importantItems}}

#### Nice-to-Have (Could Fix)

{{#niceItems}}

1. {{.}}
   {{/niceItems}}

### Focus Areas for Next Step

{{#focusAreas}}

- {{.}}
  {{/focusAreas}}

---

_Goals identified on {{date}}_
